@@ -65,6 +65,9 @@ public class CoreText extends NLS {
 	/** */
 	public static String CommitOperation_couldNotFindRepositoryMapping;
 
+	/** */
+	public static String ConfigureFetchAfterCloneTask_couldNotFetch;
+
 	/** */
 	public static String ConnectProviderOperation_connecting;
 
@@ -77,6 +80,15 @@ public class CoreText extends NLS {
 	/** */
 	public static String DeleteTagOperation_exceptionMessage;
 
+	/** */
+	public static String DiffHeaderFormat_Email;
+
+	/** */
+	public static String DiffHeaderFormat_None;
+
+	/** */
+	public static String DiffHeaderFormat_Oneline;
+
 	/** */
 	public static String DiscardChangesOperation_discardFailed;
 
@@ -213,10 +225,16 @@ public class CoreText extends NLS {
 	public static String CreateLocalBranchOperation_CreatingBranchMessage;
 
 	/** */
-	public static String CreatePatchOperation_commitRequired;
+	public static String CreatePatchOperation_repoRequired;
 
 	/** */
-	public static String CreatePatchOperation_repoRequired;
+	public static String CreatePatchOperation_cannotCreatePatchForMergeCommit;
+
+	/** */
+	public static String CreatePatchOperation_cannotCreatePatchForFirstCommit;
+
+	/** */
+	public static String CreatePatchOperation_patchFileCouldNotBeWritten;
 
 	/** */
 	public static String IndexDiffCacheEntry_reindexing;
