@@ -1,5 +1,6 @@
 /*******************************************************************************
  * Copyright (C) 2008, Shawn O. Pearce <spearce@spearce.org>
+ * Copyright (C) 2011, Robin Rosenberg
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -25,4 +26,7 @@ public class GitCorePreferences {
 	/** */
 	public static final String core_autoShareProjects =
 		"core_autoShareProjects";  //$NON-NLS-1$
+	/** */
+	public static String core_gitPrefix =
+		"core_gitPrefix"; //$NON-NLS-1$
 }
