@@ -10,6 +10,7 @@
  *******************************************************************************/
 package org.eclipse.egit.ui.test;
 
+import static org.eclipse.swtbot.eclipse.finder.waits.Conditions.waitForView;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
@@ -48,6 +49,9 @@ import org.eclipse.swtbot.swt.finder.widgets.SWTBotTable;
 import org.eclipse.swtbot.swt.finder.widgets.SWTBotTree;
 import org.eclipse.swtbot.swt.finder.widgets.SWTBotTreeItem;
 import org.eclipse.swtbot.swt.finder.widgets.TimeoutException;
+import org.eclipse.ui.IViewReference;
+import org.hamcrest.BaseMatcher;
+import org.hamcrest.Description;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTracker;
@@ -468,4 +472,34 @@ public class TestUtil {
 				ConfigConstants.CONFIG_KEY_EMAIL, TestUtil.TESTCOMMITTER_EMAIL);
 	}
 
+	public static void waitUntilViewWithGivenIdShows(final String viewId) {
+		waitForView(new BaseMatcher<IViewReference>() {
+			public boolean matches(Object item) {
+				if (item instanceof IViewReference) {
+					return viewId.equals(((IViewReference) item).getId());
+				}
+				return false;
+			}
+
+			public void describeTo(Description description) {
+				description.appendText("Wait for view with ID=" + viewId);
+			}
+		});
+	}
+
+	public static void waitUntilViewWithGivenTitleShows(final String viewTitle) {
+		waitForView(new BaseMatcher<IViewReference>() {
+			public boolean matches(Object item) {
+				if (item instanceof IViewReference)
+					return viewTitle.equals(((IViewReference) item).getTitle());
+
+				return false;
+			}
+
+			public void describeTo(Description description) {
+				description.appendText("Wait for view with title " + viewTitle);
+			}
+		});
+	}
+
 }
