@@ -268,8 +268,9 @@ public class HistoryViewTest extends LocalRepositoryTestCase {
 				// empty
 			}
 		});
-		return bot.viewById("org.eclipse.team.ui.GenericHistoryView").bot()
-				.table();
+		String genericHistoryViewId = "org.eclipse.team.ui.GenericHistoryView";
+		TestUtil.waitUntilViewWithGivenIdShows(genericHistoryViewId);
+		return bot.viewById(genericHistoryViewId).bot().table();
 	}
 
 	@Test
