@@ -23,9 +23,12 @@ import org.eclipse.egit.ui.UIText;
 import org.eclipse.egit.ui.test.ContextMenuHelper;
 import org.eclipse.egit.ui.test.TestUtil;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.operation.ModalContext;
+import org.eclipse.jgit.api.Git;
 import org.eclipse.jgit.lib.Constants;
 import org.eclipse.jgit.lib.RepositoryCache.FileKey;
 import org.eclipse.jgit.util.FS;
+import org.eclipse.jgit.util.FileUtils;
 import org.eclipse.swt.dnd.Clipboard;
 import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.dnd.Transfer;
@@ -50,6 +53,7 @@ public class GitRepositoriesViewRepoHandlingTest extends
 		GitRepositoriesViewTestBase {
 
 	private static final String REMOVE_REPOSITORY_CONTEXT_MENU_LABEL = "RepoViewRemove.label";
+
 	private static File repositoryFile;
 
 	@BeforeClass
@@ -278,7 +282,7 @@ public class GitRepositoriesViewRepoHandlingTest extends
 		shell.bot().textWithLabel(UIText.RepositorySearchDialog_directory)
 				.setText(getTestDirectory().getPath());
 		shell.bot().button(UIText.RepositorySearchDialog_Search).click();
-		shell.bot().button(IDialogConstants.OK_LABEL).click();
+		shell.bot().button(IDialogConstants.FINISH_LABEL).click();
 		refreshAndWait();
 		assertHasRepo(repositoryFile);
 	}
@@ -294,7 +298,9 @@ public class GitRepositoriesViewRepoHandlingTest extends
 								.getPluginLocalizedValue("RepoViewCloneRepository.tooltip"))
 				.click();
 		SWTBotShell shell = bot.shell(UIText.GitCloneWizard_title).activate();
-		// for some reason, textWithLabel doesn't seem to work
+		shell.bot().tree().select("URI");
+
+		shell.bot().button("Next >").click();		// for some reason, textWithLabel doesn't seem to work
 		shell.bot()
 				.textInGroup(UIText.RepositorySelectionPage_groupLocation, 0)
 				.setText(repositoryFile.getPath());
@@ -355,6 +361,49 @@ public class GitRepositoriesViewRepoHandlingTest extends
 		assertTrue(myRepoViewUtil.lookupRepository(repoFile).isBare());
 	}
 
+	@Test
+	public void testSearchDirectoryWithBareRepos() throws Exception {
+		deleteAllProjects();
+		clearView();
+		refreshAndWait();
+		assertEmpty();
+		getOrOpenView()
+				.toolbarButton(
+						myUtil.getPluginLocalizedValue("RepoViewAddRepository.tooltip"))
+				.click();
+
+		FileUtils.delete(getTestDirectory(), FileUtils.RECURSIVE
+				| FileUtils.RETRY | FileUtils.SKIP_MISSING);
+
+		Git.init().setBare(true)
+				.setDirectory(new File(getTestDirectory(), "BareRepository1"))
+				.call();
+
+		Git.init().setBare(true)
+				.setDirectory(new File(getTestDirectory(), "BareRepository2"))
+				.call();
+
+		SWTBotShell shell = bot.shell(
+				UIText.RepositorySearchDialog_AddGitRepositories).activate();
+
+		shell.bot().checkBox(UIText.RepositorySearchDialog_DeepSearch_button)
+				.deselect();
+
+		shell.bot().textWithLabel(UIText.RepositorySearchDialog_directory)
+				.setText(getTestDirectory().getPath());
+
+		shell.bot().button(UIText.RepositorySearchDialog_Search).click();
+
+		int max = 5000;
+		int slept = 0;
+		while (ModalContext.getModalLevel() > 0 && slept < max) {
+			Thread.sleep(100);
+			slept += 100;
+		}
+
+		assertEquals(2, shell.bot().tree().rowCount());
+	}
+
 	private void assertHasClonedRepo() throws Exception {
 		final SWTBotTree tree = getOrOpenView().bot().tree();
 		String text = repositoryFile.getParentFile().getName() + "Cloned";
