@@ -329,7 +329,7 @@ public abstract class AbstractSynchronizeViewTest extends
 		op.execute(null);
 	}
 
-	private void commit(String projectName) throws InterruptedException {
+	protected void commit(String projectName) throws InterruptedException {
 		showDialog(projectName, "Team", CommitAction_commit);
 
 		bot.shell(CommitDialog_CommitChanges).bot().activeShell();
