@@ -17,10 +17,12 @@ import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.allOf;
 import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.widgetOfType;
 import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.withRegex;
 import static org.hamcrest.CoreMatchers.equalTo;
+import static org.hamcrest.CoreMatchers.is;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNotSame;
 import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertTrue;
 
 import java.io.BufferedWriter;
 import java.io.ByteArrayInputStream;
@@ -31,7 +33,13 @@ import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.ResourcesPlugin;
+import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.egit.ui.UIText;
+import org.eclipse.egit.ui.internal.CommonUtils;
+import org.eclipse.jgit.api.Git;
+import org.eclipse.jgit.api.Status;
+import org.eclipse.jgit.storage.file.FileRepository;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotEditor;
 import org.eclipse.swtbot.swt.finder.SWTBot;
@@ -80,7 +88,7 @@ public class SynchronizeViewGitChangeSetModelTest extends
 		// then
 		SWTBotTree syncViewTree = bot.viewByTitle("Synchronize").bot().tree();
 		SWTBotTreeItem[] syncItems = syncViewTree.getAllItems();
-		assertEquals(GitModelWorkingTree_workingTree, syncItems[0].getText());
+		assertTrue(syncItems[0].getText().endsWith(GitModelWorkingTree_workingTree));
 	}
 
 	@Test
@@ -253,6 +261,7 @@ public class SynchronizeViewGitChangeSetModelTest extends
 	@Test public void shouldShowNonWorkspaceFileInSynchronization()
 			throws Exception {
 		// given
+		resetRepositoryToCreateInitialTag();
 		String name = "non-workspace.txt";
 		File root = new File(getTestDirectory(), REPO1);
 		File nonWorkspace = new File(root, name);
@@ -276,6 +285,7 @@ public class SynchronizeViewGitChangeSetModelTest extends
 	public void shouldShowCompareEditorForNonWorkspaceFileFromSynchronization()
 			throws Exception {
 		// given
+		resetRepositoryToCreateInitialTag();
 		String content = "file content";
 		String name = "non-workspace.txt";
 		File root = new File(getTestDirectory(), REPO1);
@@ -305,6 +315,122 @@ public class SynchronizeViewGitChangeSetModelTest extends
 		assertNotSame(left, right);
 	}
 
+	@Test
+	public void shouldStagePartialChangeInCompareEditor() throws Exception {
+		// given
+		resetRepositoryToCreateInitialTag();
+		changeFilesInProject();
+		launchSynchronization(HEAD, HEAD, true);
+		setGitChangeSetPresentationModel();
+		getCompareEditorForFileInGitChangeSet(FILE1, true).bot();
+
+		// when
+		Display.getDefault().syncExec(new Runnable() {
+			public void run() {
+				CommonUtils.runCommand("org.eclipse.compare.copyLeftToRight",
+						null);
+			}
+		});
+		bot.activeEditor().save();
+
+
+		// then file FILE1 should be in index
+		FileRepository repo = lookupRepository(repositoryFile);
+		Status status = new Git(repo).status().call();
+		assertThat(Long.valueOf(status.getChanged().size()),
+				is(Long.valueOf(1L)));
+		assertThat(status.getChanged().iterator().next(), is(PROJ1 + "/"
+				+ FOLDER + "/" + FILE1));
+	}
+
+	@Test
+	public void shouldUnStagePartialChangeInCompareEditor() throws Exception {
+		// given
+		resetRepositoryToCreateInitialTag();
+		changeFilesInProject();
+		launchSynchronization(HEAD, HEAD, true);
+		setGitChangeSetPresentationModel();
+		getCompareEditorForFileInGitChangeSet(FILE1, true).bot();
+
+		// when
+		Display.getDefault().syncExec(new Runnable() {
+			public void run() {
+				CommonUtils.runCommand("org.eclipse.compare.copyRightToLeft",
+						null);
+			}
+		});
+		bot.activeEditor().save();
+
+		// then file FILE1 should be unchanged in working tree
+		FileRepository repo = lookupRepository(repositoryFile);
+		Status status = new Git(repo).status().call();
+		assertThat(Long.valueOf(status.getModified().size()),
+				is(Long.valueOf(1)));
+		assertThat(status.getModified().iterator().next(), is(PROJ1 + "/"
+				+ FOLDER + "/" + FILE2));
+	}
+
+	public void shouldRefreshSyncResultAfterWorkspaceChange() throws Exception {
+		// given
+		String newFileName = "new.txt";
+		resetRepositoryToCreateInitialTag();
+		launchSynchronization(INITIAL_TAG, HEAD, true);
+		setGitChangeSetPresentationModel();
+		IProject proj = ResourcesPlugin.getWorkspace().getRoot()
+				.getProject(PROJ1);
+
+		// when
+		IFile newFile = proj.getFile(newFileName);
+		newFile.create(
+				new ByteArrayInputStream("content of new file".getBytes(proj
+						.getDefaultCharset())), false, null);
+		// force refresh
+		proj.refreshLocal(IResource.DEPTH_INFINITE, null);
+		Job.getJobManager().join(ResourcesPlugin.FAMILY_AUTO_BUILD, null);
+
+		// then
+		SWTBotTree syncViewTree = bot.viewByTitle("Synchronize").bot().tree();
+		SWTBotTreeItem[] syncItems = syncViewTree.getAllItems();
+		assertEquals(GitModelWorkingTree_workingTree, syncItems[0].getText());
+		syncItems[0].doubleClick(); // expand all
+		// WidgetNotFoundException will be thrown when node named 'new.txt' not
+		// exists
+		assertNotNull(syncItems[0].getNode(PROJ1));
+		assertNotNull(syncItems[0].getNode(PROJ1).getNode(newFileName));
+	}
+
+	// TODO: stabilize test and reenable it
+	@Ignore
+	@Test
+	public void shouldRefreshSyncResultAfterRepositoryChange() throws Exception {
+		// given
+		resetRepositoryToCreateInitialTag();
+		changeFilesInProject();
+		launchSynchronization(HEAD, HEAD, true);
+		setGitChangeSetPresentationModel();
+
+		// preconditions - sync result should contain two uncommitted changes
+		SWTBotTree syncViewTree = bot.viewByTitle("Synchronize").bot().tree();
+		SWTBotTreeItem[] syncItems = syncViewTree.getAllItems();
+		assertTrue(syncItems[0].getText().endsWith(GitModelWorkingTree_workingTree));
+		syncItems[0].doubleClick();
+		assertEquals(2,
+				syncItems[0].getItems()[0].getItems()[0].getItems().length);
+
+		// when
+		commit(PROJ1);
+
+		// then - synchronize view should be empty
+		SWTBot viewBot = bot.viewByTitle("Synchronize").bot();
+		@SuppressWarnings("unchecked")
+		Matcher matcher = allOf(widgetOfType(Label.class),
+				withRegex("No changes in .*"));
+
+		@SuppressWarnings("unchecked")
+		SWTBotLabel l = new SWTBotLabel((Label) viewBot.widget(matcher));
+		assertNotNull(l);
+	}
+
 	// this test always fails with cause:
 	// Timeout after: 5000 ms.: Could not find context menu with text:
 	// Synchronize
