@@ -203,6 +203,12 @@ public class UIIcons {
 	/** Annotated tag icon */
 	public final static ImageDescriptor TAG_ANNOTATED;
 
+	/** Submodules icon */
+	public final static ImageDescriptor SUBMODULES;
+
+	/** Stash icon */
+	public final static ImageDescriptor STASH;
+
 	/** base URL */
 	public final static URL base;
 
@@ -275,6 +281,8 @@ public class UIIcons {
 		MERGE = map("obj16/merge.gif"); //$NON-NLS-1$
 		TAG_ANNOTATED = map("obj16/annotated-tag.gif"); //$NON-NLS-1$
 		CREATE_REPOSITORY = map("etool16/createRepository.gif"); //$NON-NLS-1$
+		SUBMODULES = map("obj16/submodules.gif"); //$NON-NLS-1$
+		STASH = map("obj16/stash.png"); //$NON-NLS-1$
 	}
 
 	private static ImageDescriptor map(final String icon) {
