@@ -2,7 +2,7 @@
  * Copyright (C) 2008, Roger C. Soares <rogersoares@intelinet.com.br>
  * Copyright (C) 2008, Shawn O. Pearce <spearce@spearce.org>
  * Copyright (C) 2010, Matthias Sohn <matthias.sohn@sap.com>
- *
+ * Copyright (C) 2011, Daniel Megert <daniel_megert@ch.ibm.com>
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -93,6 +93,9 @@ public class UIText extends NLS {
 	/** */
 	public static String AddConfigEntryDialog_ValueLabel;
 
+	/** */
+	public static String AddSubmoduleWizard_WindowTitle;
+
 	/** */
 	public static String AddToIndexAction_addingFiles;
 
@@ -300,6 +303,9 @@ public class UIText extends NLS {
 	/** */
 	public static String ExistingOrNewPage_WrongPathErrorDialogTitle;
 
+	/** */
+	public static String GitCloneSourceProviderExtension_Local;
+
 	/** */
 	public static String GitCloneWizard_abortingCloneMsg;
 
@@ -591,6 +597,9 @@ public class UIText extends NLS {
 	/** */
 	public static String ProjectsPreferencePage_AutoShareProjects;
 
+	/** */
+	public static String ProjectsPreferencePage_RestoreBranchProjects;
+
 	/** */
 	public static String GitProjectPropertyPage_LabelBranch;
 
@@ -972,6 +981,15 @@ public class UIText extends NLS {
 	/** */
 	public static String RepositoryCommit_UserAndDate;
 
+	/** */
+	public static String RepositoryLocationPage_info;
+
+	/** */
+	public static String RepositoryLocationPage_title;
+
+	/** */
+	public static String RepositoryLocationContentProvider_errorProvidingRepoServer;
+
 	/** */
 	public static String RepositorySearchDialog_browse;
 
@@ -1128,6 +1146,9 @@ public class UIText extends NLS {
 	/** */
 	public static String SourceBranchPage_cannotCreateTemp;
 
+	/** */
+	public static String SourceBranchPage_CompositeTransportErrorMessage;
+
 	/** */
 	public static String CloneDestinationPage_title;
 
@@ -1155,6 +1176,9 @@ public class UIText extends NLS {
 	/** */
 	public static String CloneDestinationPage_browseButton;
 
+	/** */
+	public static String CloneDestinationPage_cloneSubmodulesButton;
+
 	/** */
 	public static String CloneDestinationPage_DefaultRepoFolderTooltip;
 
@@ -1614,6 +1638,12 @@ public class UIText extends NLS {
 	/** */
 	public static String HistoryPage_findbar_notFound;
 
+	/** */
+	public static String HistoryPreferencePage_MaxBranchLength;
+
+	/** */
+	public static String HistoryPreferencePage_MaxTagLength;
+
 	/** */
 	public static String PullOperationUI_ConnectionProblem;
 
@@ -1866,6 +1896,12 @@ public class UIText extends NLS {
 	/** */
 	public static String ConfigurationEditorComponent_AddButton;
 
+	/** */
+	public static String ConfigurationEditorComponent_BrowseForPrefix;
+
+	/** */
+	public static String ConfigurationEditorComponent_CannotChangeGitPrefixError;
+
 	/** */
 	public static String ConfigurationEditorComponent_ChangeButton;
 
@@ -1878,6 +1914,12 @@ public class UIText extends NLS {
 	/** */
 	public static String ConfigurationEditorComponent_EmptyStringNotAllowed;
 
+	/** */
+	public static String ConfigurationEditorComponent_GitPrefixSelectionErrorMessage;
+
+	/** */
+	public static String ConfigurationEditorComponent_GitPrefixSelectionErrorTitle;
+
 	/** */
 	public static String ConfigurationEditorComponent_KeyColumnHeader;
 
@@ -1920,6 +1962,9 @@ public class UIText extends NLS {
 	/** */
 	public static String ConfigurationEditorComponent_RemoveSubsectionTitle;
 
+	/** */
+	public static String ConfigurationEditorComponent_SelectGitInstallation;
+
 	/** */
 	public static String ConfigurationEditorComponent_ValueColumnHeader;
 
@@ -1929,6 +1974,9 @@ public class UIText extends NLS {
 	/** */
 	public static String ConfigurationEditorComponent_WrongNumberOfTokensMessage;
 
+	/** */
+	public static String ConfigureGerritWizard_title;
+
 	/** */
 	public static String GlobalConfigurationPreferencePage_systemSettingTabTitle;
 
@@ -1977,6 +2025,9 @@ public class UIText extends NLS {
 	/** */
 	public static String CommitMessageViewer_branches;
 
+	/** */
+	public static String CommitMessageViewer_MoreBranches;
+
 	/** */
 	public static String CommitMessageViewer_BuildDiffListTaskName;
 
@@ -2541,6 +2592,9 @@ public class UIText extends NLS {
 	/** */
 	public static String CheckoutDialog_Delete;
 
+	/** */
+	public static String CommitDialogPreferencePage_commitMessageHistory;
+
 	/** */
 	public static String CommitDialogPreferencePage_title;
 
@@ -2556,6 +2610,12 @@ public class UIText extends NLS {
 	/** */
 	public static String CommitDialogPreferencePage_formatting;
 
+	/** */
+	public static String CommitDialogPreferencePage_includeUntrackedFiles;
+
+	/** */
+	public static String CommitDialogPreferencePage_includeUntrackedFilesTooltip;
+
 	/** */
 	public static String CommitDialogPreferencePage_signedOffBy;
 
@@ -2583,12 +2643,6 @@ public class UIText extends NLS {
 	/** */
 	public static String DecoratorPreferencesPage_recomputeAncestorDecorationsTooltip;
 
-	/** */
-	public static String DecoratorPreferencesPage_computeRecursiveLimit;
-
-	/** */
-	public static String DecoratorPreferencesPage_computeRecursiveLimitTooltip;
-
 	/** */
 	public static String DecoratorPreferencesPage_description;
 
@@ -2613,6 +2667,9 @@ public class UIText extends NLS {
 	/** */
 	public static String DecoratorPreferencesPage_bindingBranchName;
 
+	/** */
+	public static String DecoratorPreferencesPage_bindingBranchStatus;
+
 	/** */
 	public static String DecoratorPreferencesPage_bindingDirtyFlag;
 
@@ -2793,15 +2850,18 @@ public class UIText extends NLS {
 	/** */
 	public static String RepositoriesViewContentProvider_ExceptionNodeText;
 
-	/** */
-	public static String RepositoriesViewLabelProvider_BareRepositoryMessage;
-
 	/** */
 	public static String RepositoriesViewLabelProvider_LocalNodetext;
 
 	/** */
 	public static String RepositoriesViewLabelProvider_RemoteTrackingNodetext;
 
+	/** */
+	public static String RepositoriesViewLabelProvider_StashNodeText;
+
+	/** */
+	public static String RepositoriesViewLabelProvider_SubmodulesNodeText;
+
 	/** */
 	public static String RepositoriesViewLabelProvider_SymbolicRefNodeText;
 
@@ -2919,6 +2979,12 @@ public class UIText extends NLS {
 	/** */
 	public static String GitCreateGeneralProjectPage_ProjectNameLabel;
 
+	/** */
+	public static String GitCreatePatchAction_cannotCreatePatch;
+
+	/** */
+	public static String GitCreatePatchAction_workingTreeClean;
+
 	/** */
 	public static String GitCreatePatchWizard_Browse;
 
@@ -2935,7 +3001,7 @@ public class UIText extends NLS {
 	public static String GitCreatePatchWizard_File;
 
 	/** */
-	public static String GitCreatePatchWizard_GitFormat;
+	public static String GitCreatePatchWizard_Format;
 
 	/** */
 	public static String GitCreatePatchWizard_InternalError;
@@ -2982,6 +3048,12 @@ public class UIText extends NLS {
 	/** */
 	public static String GitImportWithDirectoriesPage_SelectFolderMessage;
 
+	/** */
+	public static String GitImportWizard_errorParsingURI;
+
+	/** */
+	public static String GitImportWizard_noRepositoryInfo;
+
 	/** */
 	public static String GitImportWizard_WizardTitle;
 
@@ -3331,12 +3403,27 @@ public class UIText extends NLS {
 	/** */
 	public static String CommitEditorPage_TooltipSignedOffByCommitter;
 
+	/** */
+	public static String Header_contextMenu_copy;
+
+	/** */
+	public static String Header_contextMenu_copy_SHA1;
+	/** */
+
+	public static String Header_copy_SHA1_error_title;
+
+	/** */
+	public static String Header_copy_SHA1_error_message;
+
 	/** */
 	public static String CommitFileDiffViewer_CanNotOpenCompareEditorTitle;
 
 	/** */
 	public static String CommitFileDiffViewer_CompareMenuLabel;
 
+	/** */
+	public static String CommitFileDiffViewer_CompareWorkingDirectoryMenuLabel;
+
 	/** */
 	public static String CommitFileDiffViewer_FileDoesNotExist;
 
@@ -4129,6 +4216,36 @@ public class UIText extends NLS {
 	/** */
 	public static String StagingView_StageItemMenuLabel;
 
+	/** */
+	public static String SubmoduleAddCommand_AddError;
+
+	/** */
+	public static String SubmoduleAddCommand_JobTitle;
+
+	/** */
+	public static String SubmodulePathWizardPage_ErrorPathMustBeEmpty;
+
+	/** */
+	public static String SubmodulePathWizardPage_Message;
+
+	/** */
+	public static String SubmodulePathWizardPage_PathLabel;
+
+	/** */
+	public static String SubmodulePathWizardPage_Title;
+
+	/** */
+	public static String SubmoduleSyncCommand_SyncError;
+
+	/** */
+	public static String SubmoduleSyncCommand_Title;
+
+	/** */
+	public static String SubmoduleUpdateCommand_Title;
+
+	/** */
+	public static String SubmoduleUpdateCommand_UpdateError;
+
 	/** */
 	public static String SynchronizeWithMenu_custom;
 
