@@ -21,6 +21,7 @@ import org.eclipse.egit.ui.UIPreferences;
 import org.eclipse.egit.ui.UIText;
 import org.eclipse.egit.ui.internal.components.RepositorySelection;
 import org.eclipse.jface.dialogs.Dialog;
+import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.jface.layout.GridLayoutFactory;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.ComboViewer;
@@ -72,10 +73,18 @@ class CloneDestinationPage extends WizardPage {
 
 	private Button importProjectsButton;
 
+	private Button cloneSubmodulesButton;
+
 	private WorkingSetGroup workingSetGroup;
 
 	private String helpContext = null;
 
+	private File clonedDestination;
+
+	private Ref clonedInitialBranch;
+
+	private String clonedRemote;
+
 	CloneDestinationPage() {
 		super(CloneDestinationPage.class.getName());
 		setTitle(UIText.CloneDestinationPage_title);
@@ -183,6 +192,11 @@ class CloneDestinationPage extends WizardPage {
 					return ((Ref)element).getName().substring(Constants.R_HEADS.length());
 				return ((Ref)element).getName();
 			} });
+
+		cloneSubmodulesButton = new Button(g, SWT.CHECK);
+		cloneSubmodulesButton
+				.setText(UIText.CloneDestinationPage_cloneSubmodulesButton);
+		GridDataFactory.swtDefaults().span(2, 1).applyTo(cloneSubmodulesButton);
 	}
 
 	private void createConfigGroup(final Composite parent) {
@@ -257,6 +271,14 @@ class CloneDestinationPage extends WizardPage {
 				&& importProjectsButton.getSelection();
 	}
 
+	/**
+	 * @return true to clone submodules, false otherwise
+	 */
+	public boolean isCloneSubmodules() {
+		return cloneSubmodulesButton != null
+				&& cloneSubmodulesButton.getSelection();
+	}
+
 	/**
 	 * @return selected working sets
 	 */
@@ -308,6 +330,11 @@ class CloneDestinationPage extends WizardPage {
 	 * Check internal state for page completion status.
 	 */
 	private void checkPage() {
+		if (!cloneSettingsChanged()) {
+			setErrorMessage(null);
+			setPageComplete(true);
+			return;
+		}
 		final String dstpath = directoryText.getText();
 		if (dstpath.length() == 0) {
 			setErrorMessage(UIText.CloneDestinationPage_errorDirectoryRequired);
@@ -345,6 +372,21 @@ class CloneDestinationPage extends WizardPage {
 		setPageComplete(true);
 	}
 
+	void saveSettingsForClonedRepo() {
+		clonedDestination = getDestinationFile();
+		clonedInitialBranch = getInitialBranch();
+		clonedRemote = getRemote();
+	}
+
+	boolean cloneSettingsChanged() {
+		boolean cloneSettingsChanged = false;
+		if (clonedDestination == null || !clonedDestination.equals(getDestinationFile()) ||
+				clonedInitialBranch == null || !clonedInitialBranch.equals(getInitialBranch()) ||
+				clonedRemote == null || !clonedRemote.equals(getRemote()))
+			cloneSettingsChanged = true;
+		return cloneSettingsChanged;
+	}
+
 	private static boolean isEmptyDir(final File dir) {
 		if (!dir.exists())
 			return true;
