@@ -26,6 +26,8 @@ import org.eclipse.egit.ui.UIPreferences;
 import org.eclipse.egit.ui.UIText;
 import org.eclipse.egit.ui.UIUtils;
 import org.eclipse.egit.ui.UIUtils.IPreviousValueProposalHandler;
+import org.eclipse.egit.ui.internal.provisional.wizards.GitRepositoryInfo;
+import org.eclipse.egit.ui.internal.provisional.wizards.IRepositorySearchResult;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.jface.preference.IPreferenceStore;
@@ -64,7 +66,7 @@ import org.eclipse.ui.PlatformUI;
  * Wizard page that allows the user entering the location of a remote repository
  * by specifying URL manually or selecting a preconfigured remote repository.
  */
-public class RepositorySelectionPage extends WizardPage {
+public class RepositorySelectionPage extends WizardPage implements IRepositorySearchResult {
 
 	private static final String EMPTY_STRING = "";  //$NON-NLS-1$
 
@@ -376,6 +378,14 @@ public class RepositorySelectionPage extends WizardPage {
 		this(sourceSelection, null, presetUri);
 	}
 
+	/**
+	 * No args constructor; needed because the page is provided by the extension
+	 * point {@code org.eclipse.egit.ui.cloneSourceProvider}
+	 */
+	public RepositorySelectionPage() {
+		this(true, null);
+	}
+
 	/**
 	 * @return repository selection representing current page state.
 	 */
@@ -1001,4 +1011,12 @@ public class RepositorySelectionPage extends WizardPage {
 		return Activator.getDefault().getPreferenceStore();
 	}
 
+	public GitRepositoryInfo getGitRepositoryInfo() {
+		GitRepositoryInfo info = new GitRepositoryInfo(uri.toString());
+		info.setCredentials(user, password);
+		info.setShouldSaveCredentialsInSecureStore(true);
+		uriProposalHandler.updateProposals();
+		return info;
+	}
+
 }
