@@ -30,6 +30,7 @@ import org.eclipse.core.commands.common.NotDefinedException;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.egit.core.op.CreatePatchOperation;
+import org.eclipse.egit.core.op.CreatePatchOperation.DiffHeaderFormat;
 import org.eclipse.egit.ui.Activator;
 import org.eclipse.egit.ui.UIIcons;
 import org.eclipse.egit.ui.UIPreferences;
@@ -212,11 +213,7 @@ class CommitGraphTable {
 			@Override
 			public void mouseHover(MouseEvent e) {
 				synchronized (this) {
-					if (hoverShell != null) {
-						hoverShell.setVisible(false);
-						hoverShell.dispose();
-						hoverShell = null;
-					}
+					disposeHover();
 
 					TableItem item = table.getTable().getItem(
 							new Point(e.x, e.y));
@@ -263,11 +260,7 @@ class CommitGraphTable {
 		table.getTable().addMouseMoveListener(new MouseMoveListener() {
 			public void mouseMove(MouseEvent e) {
 				synchronized (this) {
-					if (hoverShell == null || hoverShell.isDisposed())
-						return;
-					hoverShell.setVisible(false);
-					hoverShell.dispose();
-					hoverShell = null;
+					disposeHover();
 				}
 			}
 		});
@@ -279,6 +272,7 @@ class CommitGraphTable {
 					allCommits.dispose();
 				if (renderer != null)
 					renderer.dispose();
+				disposeHover();
 			}
 		});
 
@@ -352,6 +346,13 @@ class CommitGraphTable {
 				getTableView(), site, copy));
 	}
 
+	void disposeHover() {
+		if (hoverShell == null)
+			return;
+		hoverShell.dispose();
+		hoverShell = null;
+	}
+
 	Control getControl() {
 		return table.getControl();
 	}
@@ -380,8 +381,8 @@ class CommitGraphTable {
 		table.removePostSelectionChangedListener(l);
 	}
 
-	boolean setRelativeDate(boolean booleanValue) {
-		return graphLabelProvider.setRelativeDate(booleanValue);
+	void setRelativeDate(boolean booleanValue) {
+		graphLabelProvider.setRelativeDate(booleanValue);
 	}
 
 	private boolean canDoCopy() {
@@ -617,7 +618,7 @@ class CommitGraphTable {
 			Repository repository = input.getRepository();
 			CreatePatchOperation operation = new CreatePatchOperation(
 					repository, commit);
-			operation.useGitFormat(true);
+			operation.setHeaderFormat(DiffHeaderFormat.EMAIL);
 			operation.setContextLines(CreatePatchOperation.DEFAULT_CONTEXT_LINES);
 			try {
 				operation.execute(null);
