@@ -87,7 +87,7 @@ public class GlobalConfigurationPreferencePage extends PreferencePage implements
 				SWTUtils.MARGINS_NONE);
 		TabFolder tabFolder = new TabFolder(composite, SWT.NONE);
 		tabFolder.setLayoutData(SWTUtils.createHVFillGridData());
-		userConfigEditor = new ConfigurationEditorComponent(tabFolder, userConfig, true) {
+		userConfigEditor = new ConfigurationEditorComponent(tabFolder, userConfig, true, false) {
 			@Override
 			protected void setErrorMessage(String message) {
 				GlobalConfigurationPreferencePage.this.setErrorMessage(message);
@@ -99,7 +99,7 @@ public class GlobalConfigurationPreferencePage extends PreferencePage implements
 				updateApplyButton();
 			}
 		};
-		sysConfigEditor = new ConfigurationEditorComponent(tabFolder, sysConfig, true) {
+		sysConfigEditor = new ConfigurationEditorComponent(tabFolder, sysConfig, true, true) {
 			@Override
 			protected void setErrorMessage(String message) {
 				GlobalConfigurationPreferencePage.this.setErrorMessage(message);
@@ -110,6 +110,14 @@ public class GlobalConfigurationPreferencePage extends PreferencePage implements
 				sysIsDirty = dirty;
 				updateApplyButton();
 			}
+			@Override
+			protected void setChangeSystemPrefix(String prefix) throws IOException {
+				FS.DETECTED.setGitPrefix(new File(prefix));
+				sysConfig = SystemReader.getInstance().openSystemConfig(null,
+						FS.DETECTED);
+				setConfig(sysConfig);
+			}
+
 		};
 		Control result = userConfigEditor.createContents();
 		Dialog.applyDialogFont(result);
@@ -294,7 +302,7 @@ public class GlobalConfigurationPreferencePage extends PreferencePage implements
 		} else {
 			repositoryConfig = repository.getConfig();
 		}
-		ConfigurationEditorComponent editorComponent = new ConfigurationEditorComponent(repoConfigComposite, repositoryConfig, true) {
+		ConfigurationEditorComponent editorComponent = new ConfigurationEditorComponent(repoConfigComposite, repositoryConfig, true, false) {
 			@Override
 			protected void setErrorMessage(String message) {
 				GlobalConfigurationPreferencePage.this.setErrorMessage(message);
