@@ -15,6 +15,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 
@@ -22,6 +23,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.egit.core.op.CreateLocalBranchOperation;
 import org.eclipse.egit.core.op.CreateLocalBranchOperation.UpstreamConfig;
+import org.eclipse.egit.ui.Activator;
 import org.eclipse.egit.ui.UIText;
 import org.eclipse.egit.ui.internal.CommonUtils;
 import org.eclipse.egit.ui.internal.ValidationUtils;
@@ -32,6 +34,7 @@ import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.jface.wizard.WizardPage;
 import org.eclipse.jgit.lib.ConfigConstants;
 import org.eclipse.jgit.lib.Constants;
+import org.eclipse.jgit.lib.ObjectId;
 import org.eclipse.jgit.lib.Ref;
 import org.eclipse.jgit.lib.RefDatabase;
 import org.eclipse.jgit.lib.Repository;
@@ -101,6 +104,11 @@ class CreateBranchPage extends WizardPage {
 
 	private Text nameText;
 
+	/**
+	 * Whether the contents of {@code nameText} is a suggestion or was entered by the user.
+	 */
+	private boolean nameIsSuggestion;
+
 	private Button checkout;
 
 	private Combo branchCombo;
@@ -191,7 +199,27 @@ class CreateBranchPage extends WizardPage {
 		if (this.myBaseCommit != null) {
 			this.branchCombo.add(myBaseCommit.name());
 			this.branchCombo.setText(myBaseCommit.name());
-			this.branchCombo.setEnabled(false);
+			try {
+				Map<String, Ref> map = myRepository.getRefDatabase().getRefs(
+						Constants.R_HEADS);
+				for (Entry<String, Ref> entry : map.entrySet()) {
+					if (entry.getValue().getLeaf().getObjectId()
+							.equals(myBaseCommit))
+						this.branchCombo.add(entry.getValue().getName());
+				}
+				map = myRepository.getRefDatabase()
+						.getRefs(Constants.R_REMOTES);
+				for (Entry<String, Ref> entry : map.entrySet()) {
+					if (entry.getValue().getLeaf().getObjectId()
+							.equals(myBaseCommit))
+						this.branchCombo.add(entry.getValue().getName());
+				}
+			} catch (IOException e) {
+				// bad luck, we can't extend the drop down; let's log an error
+				Activator.logError(
+						"Exception while trying to find Refs for Commit", e); //$NON-NLS-1$
+			}
+			this.branchCombo.setEnabled(this.branchCombo.getItemCount() > 1);
 		} else {
 			List<String> refs = new ArrayList<String>();
 			RefDatabase refDatabase = myRepository.getRefDatabase();
@@ -199,9 +227,10 @@ class CreateBranchPage extends WizardPage {
 				for (Ref ref : refDatabase.getAdditionalRefs())
 					refs.add(ref.getName());
 
-				Set<Entry<String, Ref>> entrys = refDatabase.getRefs(RefDatabase.ALL).entrySet();
+				Set<Entry<String, Ref>> entrys = refDatabase.getRefs(
+						RefDatabase.ALL).entrySet();
 				for (Entry<String, Ref> ref : entrys)
-						refs.add(ref.getValue().getName());
+					refs.add(ref.getValue().getName());
 			} catch (IOException e1) {
 				// ignore here
 			}
@@ -210,19 +239,21 @@ class CreateBranchPage extends WizardPage {
 			for (String refName : refs)
 				this.branchCombo.add(refName);
 
-			this.branchCombo.addSelectionListener(new SelectionAdapter() {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					upstreamConfig = getDefaultUpstreamConfig(myRepository,
-							branchCombo.getText());
-					checkPage();
-				}
-			});
 			// select the current branch in the drop down
 			if (myBaseRef != null)
 				this.branchCombo.setText(myBaseRef);
 		}
 
+		this.branchCombo.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				String ref = branchCombo.getText();
+				suggestBranchName(ref);
+				upstreamConfig = getDefaultUpstreamConfig(myRepository, ref);
+				checkPage();
+			}
+		});
+
 		Label nameLabel = new Label(main, SWT.NONE);
 		nameLabel.setText(UIText.CreateBranchPage_BranchNameLabel);
 
@@ -238,6 +269,11 @@ class CreateBranchPage extends WizardPage {
 				nameText.setFocus();
 			}
 		});
+		nameText.addModifyListener(new ModifyListener() {
+			public void modifyText(ModifyEvent e) {
+				nameIsSuggestion = false;
+			}
+		});
 		// enable testing with SWTBot
 		nameText.setData("org.eclipse.swtbot.widget.key", "BranchName"); //$NON-NLS-1$ //$NON-NLS-2$
 		GridDataFactory.fillDefaults().grab(true, false).applyTo(nameText);
@@ -322,13 +358,7 @@ class CreateBranchPage extends WizardPage {
 		Dialog.applyDialogFont(main);
 		setControl(main);
 		nameText.setFocus();
-		String targetName = getProposedTargetName(myBaseRef);
-		if (targetName != null) {
-			nameText.setText(targetName);
-			nameText.selectAll();
-		} else
-			// in any case, we will have to enter the name
-			setPageComplete(false);
+		suggestBranchName(myBaseRef);
 		checkPage();
 		// add the listener just now to avoid unneeded checkPage()
 		nameText.addModifyListener(new ModifyListener() {
@@ -345,8 +375,11 @@ class CreateBranchPage extends WizardPage {
 			gd.exclude = !branchCombo.getText().startsWith(Constants.R_HEADS);
 			warningComposite.setVisible(!gd.exclude);
 
+			warningComposite.getParent().getParent().layout(true);
+
+			boolean showRebase = !branchCombo.getText().startsWith(Constants.R_TAGS) && !ObjectId.isId(branchCombo.getText());
 			gd = (GridData) upstreamConfigGroup.getLayoutData();
-			gd.exclude = branchCombo.getText().startsWith(Constants.R_TAGS);
+			gd.exclude = !showRebase;
 			upstreamConfigGroup.setVisible(!gd.exclude);
 
 			upstreamConfigGroup.getParent().layout(true);
@@ -403,7 +436,7 @@ class CreateBranchPage extends WizardPage {
 
 		final CreateLocalBranchOperation cbop;
 
-		if (myBaseCommit != null)
+		if (myBaseCommit != null && this.branchCombo.getText().equals(myBaseCommit.name()))
 			cbop = new CreateLocalBranchOperation(myRepository, newRefName,
 					myBaseCommit);
 		else
@@ -453,4 +486,15 @@ class CreateBranchPage extends WizardPage {
 			return UpstreamConfig.REBASE;
 		return UpstreamConfig.MERGE;
 	}
+
+	private void suggestBranchName(String ref) {
+		if (nameText.getText().length() == 0 || nameIsSuggestion) {
+			String branchNameSuggestion = getProposedTargetName(ref);
+			if (branchNameSuggestion != null) {
+				nameText.setText(branchNameSuggestion);
+				nameText.selectAll();
+				nameIsSuggestion = true;
+			}
+		}
+	}
 }
