@@ -13,6 +13,7 @@ package org.eclipse.egit.ui.internal.repository;
 
 import java.io.File;
 import java.io.IOException;
+import java.text.MessageFormat;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -23,6 +24,7 @@ import org.eclipse.egit.core.Activator;
 import org.eclipse.egit.ui.UIIcons;
 import org.eclipse.egit.ui.UIText;
 import org.eclipse.egit.ui.internal.GitLabelProvider;
+import org.eclipse.egit.ui.internal.repository.tree.StashedCommitNode;
 import org.eclipse.egit.ui.internal.repository.tree.RepositoryTreeNode;
 import org.eclipse.egit.ui.internal.repository.tree.RepositoryTreeNodeType;
 import org.eclipse.egit.ui.internal.repository.tree.command.ToggleBranchCommitCommand;
@@ -261,6 +263,73 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 		}
 	}
 
+	/**
+	 * Get styled text for submodule repository node
+	 *
+	 * @param node
+	 * @return styled string
+	 */
+	protected StyledString getStyledTextForSubmodule(RepositoryTreeNode node) {
+		StyledString string = new StyledString();
+		Repository repository = (Repository) node.getObject();
+		String path = Repository.stripWorkDir(node.getParent().getRepository()
+				.getWorkTree(), repository.getWorkTree());
+		string.append(path);
+
+		Ref head;
+		try {
+			head = repository.getRef(Constants.HEAD);
+		} catch (IOException e) {
+			return string;
+		}
+		if (head != null) {
+			string.append(' ');
+			string.append('[', StyledString.DECORATIONS_STYLER);
+			if (head.isSymbolic())
+				string.append(
+						Repository.shortenRefName(head.getLeaf().getName()),
+						StyledString.DECORATIONS_STYLER);
+			else if (head.getObjectId() != null)
+				string.append(head.getObjectId().abbreviate(7).name(),
+						StyledString.DECORATIONS_STYLER);
+			string.append(']', StyledString.DECORATIONS_STYLER);
+			if (verboseBranchMode && head.getObjectId() != null) {
+				RevWalk walk = new RevWalk(repository);
+				RevCommit commit;
+				try {
+					commit = walk.parseCommit(head.getObjectId());
+					string.append(' ');
+					string.append(commit.getShortMessage(),
+							StyledString.QUALIFIER_STYLER);
+				} catch (IOException ignored) {
+					// Ignored
+				}
+			}
+		}
+		return string;
+	}
+
+	/**
+	 * Get styled text for commit node
+	 *
+	 * @param node
+	 * @return styled string
+	 */
+	protected StyledString getStyledTextForCommit(StashedCommitNode node) {
+		StyledString string = new StyledString();
+		RevCommit commit = node.getObject();
+		string.append(MessageFormat.format("{0}@'{'{1}'}'", //$NON-NLS-1$
+				Constants.STASH, Integer.valueOf(node.getIndex())));
+		string.append(' ');
+		string.append('[', StyledString.DECORATIONS_STYLER);
+		string.append(commit.abbreviate(7).name(),
+				StyledString.DECORATIONS_STYLER);
+		string.append(']', StyledString.DECORATIONS_STYLER);
+		string.append(' ');
+		string.append(commit.getShortMessage(), StyledString.QUALIFIER_STYLER);
+		return string;
+	}
+
 	public StyledString getStyledText(Object element) {
 		if (!(element instanceof RepositoryTreeNode))
 			return null;
@@ -270,8 +339,10 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 		try {
 			switch (node.getType()) {
 			case REPO:
-				Repository repository = (Repository) node.getObject();
-				return getStyledTextFor(repository);
+				if (node.getParent() != null
+						&& node.getParent().getType() == RepositoryTreeNodeType.SUBMODULES)
+					return getStyledTextForSubmodule(node);
+				return getStyledTextFor((Repository) node.getObject());
 			case ADDITIONALREF:
 				Ref ref = (Ref) node.getObject();
 				// shorten the name
@@ -295,15 +366,8 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 				StyledString dirString = new StyledString(
 						UIText.RepositoriesView_WorkingDir_treenode);
 				dirString.append(" - ", StyledString.QUALIFIER_STYLER); //$NON-NLS-1$
-				if (node.getRepository().isBare()) {
-					dirString
-							.append(
-									UIText.RepositoriesViewLabelProvider_BareRepositoryMessage,
-									StyledString.QUALIFIER_STYLER);
-				} else {
-					dirString.append(node.getRepository().getWorkTree()
-							.getAbsolutePath(), StyledString.QUALIFIER_STYLER);
-				}
+				dirString.append(node.getRepository().getWorkTree()
+						.getAbsolutePath(), StyledString.QUALIFIER_STYLER);
 				return dirString;
 
 			case REF:
@@ -322,6 +386,8 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 					}
 				}
 				return styled;
+			case STASHED_COMMIT:
+				return getStyledTextForCommit((StashedCommitNode) node);
 			case PUSH:
 				// fall through
 			case FETCH:
@@ -346,6 +412,10 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 				// fall through
 			case REMOTE:
 				// fall through
+			case SUBMODULES:
+				// fall through
+			case STASH:
+				// fall through
 			case ERROR: {
 				String label = getSimpleText(node);
 				if (label != null)
@@ -385,6 +455,15 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 			return UIText.RepositoriesViewLabelProvider_SymbolicRefNodeText;
 		case REMOTES:
 			return UIText.RepositoriesView_RemotesNodeText;
+		case SUBMODULES:
+			return UIText.RepositoriesViewLabelProvider_SubmodulesNodeText;
+		case STASH:
+			return UIText.RepositoriesViewLabelProvider_StashNodeText;
+		case STASHED_COMMIT:
+			return MessageFormat.format(
+					"{0}@'{'{1}'}'", //$NON-NLS-1$
+					Constants.STASH,
+					Integer.valueOf(((StashedCommitNode) node).getIndex()));
 		case REF:
 			// fall through
 		case TAG: {
@@ -413,13 +492,8 @@ public class RepositoriesViewLabelProvider extends GitLabelProvider implements
 			return refName;
 		}
 		case WORKINGDIR:
-			if (node.getRepository().isBare())
-				return UIText.RepositoriesView_WorkingDir_treenode
-						+ " - " //$NON-NLS-1$
-						+ UIText.RepositoriesViewLabelProvider_BareRepositoryMessage;
-			else
-				return UIText.RepositoriesView_WorkingDir_treenode + " - " //$NON-NLS-1$
-						+ node.getRepository().getWorkTree().getAbsolutePath();
+			return UIText.RepositoriesView_WorkingDir_treenode + " - " //$NON-NLS-1$
+					+ node.getRepository().getWorkTree().getAbsolutePath();
 		case REMOTE:
 			// fall through
 		case PUSH:
